@@ -271,8 +271,8 @@ void encode_cbor_with_packed_strings()
   ]
 )");
 
-    cbor::cbor_options options;
-    options.pack_strings(true);
+    auto options = cbor::cbor_options{}
+        .pack_strings(true);
     std::vector<uint8_t> buf;
 
     cbor::encode_cbor(j, buf, options);
