@@ -126,7 +126,7 @@ struct own_vector : std::vector<int64_t> { using  std::vector<int64_t>::vector;
 
 namespace jsoncons {
 
-template<class Json>
+template <typename Json>
 struct json_type_traits<Json, own_vector> 
 {
     static bool is(const Json& j) noexcept
