@@ -7,9 +7,9 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t *data, std::size_t size)
 {
         std::string input(reinterpret_cast<const char*>(data), size);
         json_decoder<ojson> decoder;
-        csv::csv_options options;
-        options.assume_header(true);
-        options.mapping_kind(csv::csv_mapping_kind::n_rows);
+        auto options = csv::csv_options{}
+            .assume_header(true)
+            .mapping_kind(csv::csv_mapping_kind::n_rows);
         try {
                 csv::csv_string_reader reader1(input, decoder, options);
                 reader1.read();
