@@ -26,7 +26,7 @@ namespace msgpack {
 
     enum class msgpack_container_type {object, array};
 
-    template<class Sink=jsoncons::binary_stream_sink,class Allocator=std::allocator<char>>
+    template <typename Sink=jsoncons::binary_stream_sink,typename Allocator=std::allocator<char>>
     class basic_msgpack_encoder final : public basic_json_visitor<char>
     {
         enum class decimal_parse_state { start, integer, exp1, exp2, fraction1 };
@@ -736,17 +736,6 @@ namespace msgpack {
     using msgpack_stream_encoder = basic_msgpack_encoder<jsoncons::binary_stream_sink>;
     using msgpack_bytes_encoder = basic_msgpack_encoder<jsoncons::bytes_sink<std::vector<uint8_t>>>;
 
-    #if !defined(JSONCONS_NO_DEPRECATED)
-    JSONCONS_DEPRECATED_MSG("Instead, use msgpack_bytes_encoder") typedef msgpack_bytes_encoder msgpack_bytes_serializer;
-
-    template<class Sink=jsoncons::binary_stream_sink>
-    using basic_msgpack_serializer = basic_msgpack_encoder<Sink>; 
-
-    JSONCONS_DEPRECATED_MSG("Instead, use msgpack_stream_encoder") typedef msgpack_stream_encoder msgpack_encoder;
-    JSONCONS_DEPRECATED_MSG("Instead, use msgpack_stream_encoder") typedef msgpack_stream_encoder msgpack_serializer;
-    JSONCONS_DEPRECATED_MSG("Instead, use msgpack_bytes_encoder") typedef msgpack_bytes_encoder msgpack_buffer_serializer;
-    #endif
-
 } // namespace msgpack
 } // namespace jsoncons
 
