@@ -127,8 +127,8 @@ TEST_CASE("cbor typed array tests")
 
         auto u = cbor::decode_cbor<std::vector<uint8_t>>(input);
         std::vector<uint8_t> v;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, v, options);
         CHECK((v == input));
     }
@@ -152,8 +152,8 @@ TEST_CASE("cbor typed array tests")
 
         auto u = cbor::decode_cbor<std::vector<uint16_t>>(input);
         std::vector<uint8_t> v;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, v, options);
         check_native(std::integral_constant<bool,jsoncons::endian::native == jsoncons::endian::big>(),
                      input, v);
@@ -179,8 +179,8 @@ TEST_CASE("cbor typed array tests")
 
         auto u = cbor::decode_cbor<std::vector<uint32_t>>(input);
         std::vector<uint8_t> v;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, v, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::big>(),
             input, v);
@@ -207,8 +207,8 @@ TEST_CASE("cbor typed array tests")
 
         auto u = cbor::decode_cbor<std::vector<uint64_t>>(input);
         std::vector<uint8_t> v;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, v, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::big>(),
             input, v);
@@ -277,8 +277,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(w[2] == (std::numeric_limits<uint16_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
@@ -318,8 +318,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(v[2] == (std::numeric_limits<uint32_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
@@ -352,8 +352,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(u[2] == (std::numeric_limits<uint64_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
@@ -378,8 +378,8 @@ TEST_CASE("cbor typed array tests")
         auto u = cbor::decode_cbor<std::vector<int8_t>>(input);
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
@@ -422,8 +422,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(w[2] == (std::numeric_limits<int16_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::big>(),
             input, buf);
@@ -461,8 +461,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(v[2] == (std::numeric_limits<int32_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::big>(),
             input, buf);
@@ -493,8 +493,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(u[2] == (std::numeric_limits<int64_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::big>(),
             input, buf);
@@ -539,8 +539,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(w[2] == (std::numeric_limits<int16_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
@@ -579,8 +579,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(v[2] == (std::numeric_limits<int32_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
@@ -614,8 +614,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(u[2] == (std::numeric_limits<int64_t>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
@@ -663,8 +663,8 @@ TEST_CASE("cbor typed array tests")
         auto u = cbor::decode_cbor<std::vector<float>>(input);
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::big>(),
             input, buf);
@@ -687,8 +687,8 @@ TEST_CASE("cbor typed array tests")
         auto u = cbor::decode_cbor<std::vector<double>>(input);
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::big>(),
             input, buf);
@@ -762,8 +762,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(u[1] == (std::numeric_limits<float>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
@@ -793,8 +793,8 @@ TEST_CASE("cbor typed array tests")
         CHECK(u[1] == (std::numeric_limits<double>::max)());
 
         std::vector<uint8_t> buf;
-        cbor::cbor_options options;
-        options.use_typed_arrays(true);
+        auto options = cbor::cbor_options{}
+            .use_typed_arrays(true);
         cbor::encode_cbor(u, buf, options);
         check_native(std::integral_constant<bool, jsoncons::endian::native == jsoncons::endian::little>(),
             input, buf);
