@@ -12,7 +12,7 @@
 
 using namespace jsoncons;
 
-template<class CharT>
+template <typename CharT>
 std::basic_string<CharT> float_to_string(double val, int precision)
 {
     jsoncons::detail::write_double print(float_chars_format::general,precision);
