@@ -743,9 +743,9 @@ TEST_CASE("test_is")
     obj["field2"] = -10;
     obj["field3"] = 10U;
 
-    CHECK(obj["field1"].storage_kind() == jsoncons::json_storage_kind::int64_value);
-    CHECK(obj["field2"].storage_kind() == jsoncons::json_storage_kind::int64_value);
-    CHECK(obj["field3"].storage_kind() == jsoncons::json_storage_kind::uint64_value);
+    CHECK(obj["field1"].storage_kind() == jsoncons::json_storage_kind::int64);
+    CHECK(obj["field2"].storage_kind() == jsoncons::json_storage_kind::int64);
+    CHECK(obj["field3"].storage_kind() == jsoncons::json_storage_kind::uint64);
 
     CHECK_FALSE(obj["field1"].is<std::string>());
     CHECK(obj["field1"].is<short>());
@@ -783,7 +783,7 @@ TEST_CASE("test_is2")
 {
     json obj = json::parse("{\"field1\":10}");
 
-    CHECK(obj["field1"].storage_kind() == jsoncons::json_storage_kind::uint64_value);
+    CHECK(obj["field1"].storage_kind() == jsoncons::json_storage_kind::uint64);
 
     CHECK_FALSE(obj["field1"].is<std::string>());
     CHECK(obj["field1"].is<int>());
