@@ -16,16 +16,16 @@ using namespace jsoncons;
 TEST_CASE("test_small_string")
 {
     json s("ABCD");
-    CHECK(s.storage_kind() == jsoncons::json_storage_kind::short_string_value);
+    CHECK(s.storage_kind() == jsoncons::json_storage_kind::short_str);
     CHECK(s.as<std::string>() == std::string("ABCD"));
 
     json t(s);
-    CHECK(t.storage_kind() == jsoncons::json_storage_kind::short_string_value);
+    CHECK(t.storage_kind() == jsoncons::json_storage_kind::short_str);
     CHECK(t.as<std::string>() == std::string("ABCD"));
 
     json q;
     q = s;
-    CHECK(q.storage_kind() == jsoncons::json_storage_kind::short_string_value);
+    CHECK(q.storage_kind() == jsoncons::json_storage_kind::short_str);
     CHECK(q.as<std::string>() == std::string("ABCD"));
 }
 
