@@ -101,13 +101,7 @@ TEST_CASE("jsonschema draft2020-12 tests")
 {
     SECTION("issues")
     {
-        //jsonschema_tests("./jsonschema/issues/draft2020-12/issue-email.json",
-        //    jsonschema::evaluation_options{}.default_version(jsonschema::schema_version::draft202012()).
-        //    require_format_validation(true));
-        //jsonschema_tests("./jsonschema/JSON-Schema-Test-Suite/tests/draft2020-12/optional/format/email.json",
-        //    jsonschema::evaluation_options{}.default_version(jsonschema::schema_version::draft202012()).
-        //        require_format_validation(true));
-        //jsonschema_tests("./jsonschema/JSON-Schema-Test-Suite/tests/draft2020-12/vocabulary.json");
+        jsonschema_tests("./jsonschema/issues/draft2020-12/issue-521.json");
     }
 //#if 0
     SECTION("more_tests")
@@ -182,7 +176,8 @@ TEST_CASE("jsonschema draft2020-12 tests")
         jsonschema_tests("./jsonschema/JSON-Schema-Test-Suite/tests/draft2020-12/optional/dependencies-compatibility.json",
             jsonschema::evaluation_options{}.default_version(jsonschema::schema_version::draft202012()).
                 compatibility_mode(true));
-    
+        jsonschema_tests("./jsonschema/JSON-Schema-Test-Suite/tests/draft2020-12/optional/bignum.json");
+
         // format tests
         jsonschema_tests("./jsonschema/JSON-Schema-Test-Suite/tests/draft2020-12/optional/format/date.json",
             jsonschema::evaluation_options{}.default_version(jsonschema::schema_version::draft202012()).
